/**
 * @file
 * Javascript RC4 symmetric cipher encryption/decryption
 *
 * @see https://gist.github.com/farhadi/2185197
 */

/**
 * RC4 symmetric cipher encryption/decryption.
 *
 * @param string $key
 *   secret key for encryption/decryption
 * @param string $str
 *   string to be encrypted/decrypted
 *
 * @return string
 *   resulton string of RC4 encryption/decryption
 */
function _rc4_email_rc4(key, str) {
  var s = [], j = 0, x, res = '';
  for (var i = 0; i < 256; i++) {
    s[i] = i;
  }
  for (i = 0; i < 256; i++) {
    j = (j + s[i] + key.charCodeAt(i % key.length)) % 256;
    x = s[i];
    s[i] = s[j];
    s[j] = x;
  }
  i = 0;
  j = 0;
  for (var y = 0; y < str.length; y++) {
    i = (i + 1) % 256;
    j = (j + s[i]) % 256;
    x = s[i];
    s[i] = s[j];
    s[j] = x;
    res += String.fromCharCode(str.charCodeAt(y) ^ s[(s[i] + s[j]) % 256]);
  }
  return res;
}
